@@ -34,9 +34,16 @@ class DiscreteEnv(gym.Env):
 
     #set range for obs space
     #? not all values should be equaly likely to be sampled, this is missing here
-    #? can I restrict the sampling space when an episode is run?  
-    self.min_Xas=np.array([min(self.df[["Xa"]]), min(self.df[["Xs"]])])
-    self.max_Xas=np.array([max(self.df[["Xa"]]), max(self.df[["Xs"]])])
+    #? can I restrict the sampling space when an episode is run?
+    self.minXa1 = pd.to_numeric(min(self.df[["Xa"]].values.flatten()))
+    self.minXs1 = pd.to_numeric(min(self.df[["Xs"]].values.flatten()))
+    
+    self.maxXa1 = pd.to_numeric(max(self.df[["Xa"]].values.flatten()))
+    self.maxXs1 = pd.to_numeric(max(self.df[["Xs"]].values.flatten()))
+    
+    self.min_Xas=np.array([np.float32(self.minXa1), np.float32(self.minXs1)])
+    self.max_Xas=np.array([np.float32(self.maxXa1), np.float32(self.maxXs1)])
+    
     
    
     #set ACTION SPACE
